@@ -1,6 +1,6 @@
 #
 # ovirt-hosted-engine-setup -- ovirt hosted engine setup
-# Copyright (C) 2013-2014 Red Hat, Inc.
+# Copyright (C) 2013-2017 Red Hat, Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -23,14 +23,12 @@
 from otopi import util
 
 from . import add_host
-from . import fqdn
 from . import os_install
 
 
 @util.export
 def createPlugins(context):
     os_install.Plugin(context=context)
-    fqdn.Plugin(context=context)
     add_host.Plugin(context=context)
 
 
